@@ -10,7 +10,14 @@ import logging
 
 
 def https_only(method):
-    """Decorate method with this to ensure request will be served only via HTTPS."""
+    """Decorate request handler's method with this decorator to ensure request
+    will be served only via HTTPS.
+
+    Because decorator is using `self.request.protocol` variable make sure
+    ``xheaders`` is set to `True`::
+
+        tornado.httpserver.HTTPServer(tornado.web.Application(urls, **settings), xheaders=True)
+    """
     @functools.wraps(method)
     def wrapper(self, *args, **kwargs):
         if self.request.protocol != "https":
