@@ -12,6 +12,18 @@ from pprint import pformat
 
 class AppStatus(tornado.web.RequestHandler):
     def test(self, reply):
+        """Override to implement concrete tests.
+
+        Reply dictionary must consists three keys which values must be lists or tuples:
+
+        ``reply["info"]`` — list containing any usefull information about web application state
+
+        ``reply["warnings"]`` — anything that looks bad but doesn't affect application
+
+        ``reply["errors"]`` — list of errors
+
+        `reply` dictionary is pre-filled, so it's not a good idea to ignore existing values.
+        """
         reply["warnings"].append("Webapp status tests are not implemented, yet")
 
     def get(self, format):
