@@ -13,14 +13,18 @@ SessionException = Exception
 
 class AbstractSession(object):
     def __init__(self, conn, session_id=None, auto=True, collection="sessions"):
-        self.data = {}
-        self.conn = conn
-        self.collection = collection
-        self.session_id = session_id if session_id else uuid1()
-        self.auto = auto
-        if self.auto:
+        self._data = dict()
+        self._conn = conn
+        self._collection = collection
+        self._session_id = session_id if session_id else unicode(uuid1())
+        self._auto = auto
+        logging.debug("Session initialization: %s"%self._session_id)
+        if self._auto:
             self.load()
 
+    def id(self):
+        return self._session_id
+
     def save(self):
         raise SessionException("Concrete .save() method is not implemented")
 
@@ -28,17 +32,18 @@ class AbstractSession(object):
         raise SessionException("Concrete .load() method is not implemented")
 
     def get(self, key, default=None):
-        return self.data[key] if self.data.has_key(key) else default
+        return self._data[key] if self._data.has_key(key) else default
 
     def set(self, key, value):
-        self.data[key] = value
-        if self.auto:
+        logging.debug("SESSION DATA: %s"%pprint.pformat(self._data))
+        self._data[key] = value
+        if self._auto:
             self.save()
         return value
 
     def delete(self, key):
-        del self.data[key]
-        if self.auto:
+        del self._data[key]
+        if self._auto:
             self.save()
 
 try:
@@ -46,10 +51,11 @@ try:
 
     class MongoSession(AbstractSession):
         def save(self):
-            self.conn[self.collection].save({"_id": self.session_id}, self.data)
+            self._conn[self._collection].save({"_id": self._session_id}, self._data)
 
         def load(self):
-            self.data = self.conn[self.collection].find_one({"_id": self.session_id})
+            loaded = self._conn[self._collection].find_one({"_id": self._session_id})
+            self._data = loaded if loaded else dict()
 
 except ImportError:
     pass
